.. _install-git:

=============
 Install Git
=============

Go to https://git-scm.com/book/en/v2/Getting-Started-Installing-Git for the official and up-to-date
instructions on how to install Git on your platform.

.. include:: links.inc
